Welcome to pyARS's documentation!
======================================
Copyright (c) 2018 Be The Match operated by National Marrow Donor Program. All Rights Reserved.

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation

   pyard

   usage
   contributing
   authorshistory

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
